require 'test/unit'
require 'more-assertions'
require 'app'
require 'configuration'
require 'rexml/document'
require 'path-cache.rb'
require 'renderer'
include REXML

### Assertions

# Assertions about rendering

def assert_page_has_action(action)
  assert_true(XPath.first(@doc, "//form[@name='#{action}']"))
end

def assert_page_has_no_action(action)
  assert_equal(nil, XPath.first(@doc, "//form[@name='#{action}']"))
end

def assert_page_title_matches(regexp)
  assert_match(regexp, XPath.first(@doc, '//title').text)
end

def assert_page_has_popup_link(link)
  assert_true(@page.include?(%Q{popup('#{link}')}))
end

# Assertions about App template handling

def assert_app_fills_template_with_action(template_name, expected_action)
  @app.fill(template_name) { | action |
    assert_equal(expected_action, action)
    return
  }
  fail
end

def assert_app_ignores_template(template_name)
  assert_equal(nil,
               @app.fill(template_name) {fail} )
end


### Test scaffolding methods

def given_app_with(&block)
  @app = Configuration.new(&block).make_app
end

def when_rendering(page_name)
  @page = page(page_name)
  @doc = REXML::Document.new(@page)
  yield
end
# Note that having when_rendering take a block is entirely
# gratuitous. It just seems to look better that way.


def page(page_name)
  Renderer.new(@app).send(page_name)
end

