require 'pp'
require 'uri'

TEST_HOST="http://localhost:8080"
TEST_HOST_ROOT = TEST_HOST+'/'

# As the app has evolved, some action names have changed, which breaks
# all the old tests that refer to them. (The very oldest tests refer
# to them with 'press' commands; newer ones sometimes make assertions
# about them.)  We don't want to update the old tests - if we must
# update them, they should be rewritten as declarative tests. So just
# fix up the old names here.

def update_action_name(action)
  case action
  when :new_case
    :want_new_case_form
  when :add_audit
    :want_add_audit_form
  when :add_visit
    :want_add_visit_form
  else
    action
  end
end



module PageAssertions
  require 'test/unit/assertions'
  include Test::Unit::Assertions
  require 'rexml/document'
  include REXML

  def assert_page_has_no_action(action)
    action = update_action_name(action)
    page = REXML::Document.new(@browser.current_page)
    assert_equal(nil, XPath.first(page, "//form[@name='#{action}']"))
  end

  def assert_page_title_matches(regexp)
    page = REXML::Document.new(@browser.current_page)
    assert_match(regexp, XPath.first(page, '//title').text)
  end
end


module Test
  module Unit
    class TestCase
      def method_missing(symbol, *args)
        @browser.send(symbol, *args)
      end
    end
  end
end
        
module ServerControl
  def start_server_on(host)
    @server_pid = Process.fork {
      require 'server'
      require 'app'
      AppWebInterface.new(App.new)
    }
    await_server_at(host)
  end

  def await_server_at(host_uri)
    uri = URI.parse(host_uri)
    host, port = uri.host, uri.port
    while true
      begin
        Net::HTTP.start(host, port) { | http |
          response = http.get("/ping")
          raise "try again" unless response.is_a?(Net::HTTPOK)
        }
      rescue
        sleep 0.1
      else
        break
      end
    end
  end

  def stop_server
    Process.kill("INT", @server_pid)
    Process.wait(@server_pid)
  end
end
