require 'test/unit'
require 'browser'
require 'test-util'
require 'bigger-browser-gestures'


class WorkflowTestCase < Test::Unit::TestCase
  include ServerControl

  def setup
    super
    start_server_on(TEST_HOST)
  end

  def teardown
    stop_server
    super
  end

  # Test::Unit has an annoying habit of telling me when there's no test in
  # a utility superclass. That can be avoided by defining default_test to
  # be an empty method. However, that still runs setup and teardown, and
  # I don't want to spend the time in an extra server session. 
  def run(*args)
    super unless self.class == WorkflowTestCase
  end
  
end

class DoctorDawn
  def initialize
    @browser = Browser.new
  end
  
  def logs_in
    @browser.go(TEST_HOST_ROOT)
    @browser.login("dmorin", "cowz are kool")
  end
  
  def adds_a_case
    @browser.new_case('betsy',  '213')
  end

  def adds_a_visit
    @browser.new_visit('milk fever', '100', '')
  end

  # Assertions
  include PageAssertions

  def should_be_on_the_main_page
    assert_page_title_matches(/Cases Available to Dmorin/)
  end

  def should_be_on_the_case_display_page
    assert_page_title_matches(/^Case \d+/)
  end
  alias_method :should_be_back_on_the_case_display_page,
               :should_be_on_the_case_display_page
end




class WorkflowTests < WorkflowTestCase

  def setup
    super
    @dr_dawn = DoctorDawn.new
  end

  def test_normal_new_patient_workflow
    @dr_dawn.logs_in
           (@dr_dawn.should_be_on_the_main_page)
    @dr_dawn.adds_a_case
           (@dr_dawn.should_be_on_the_case_display_page)
    @dr_dawn.adds_a_visit
           (@dr_dawn.should_be_back_on_the_case_display_page)
  end

end


